==> eiffelstudio-18.07.10.1981.tar: F_code/C9/co426.c <==
/*
 * Code for class CONF_ERROR_FILE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co426.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_ERROR_FILE}.make */
void F967_8576 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 966, Current, 0, 1, 12349);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTEE;
}

/* {CONF_ERROR_FILE}.file */
EIF_REFERENCE F967_8578 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CONF_ERROR_FILE}.orig_file */
EIF_REFERENCE F967_8579 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {CONF_ERROR_FILE}.config */
EIF_REFERENCE F967_8580 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {CONF_ERROR_FILE}.text */
EIF_REFERENCE F967_8581 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(7);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLR(4,tr2);
	RTLR(5,loc3);
	RTLR(6,loc4);
	RTLIU(7);
	
	RTEAA("text", 966, Current, 4, 0, 12354);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = RTMS_EX_H("iron:",5,1920711738);
		tb2 = F1062_9301(loc2, tr1);
		tb1 = tb2;
	}
	if (tb1) {
		RTHOOK(2);
		tr1 = RTMS32_EX_H("C\000\000\000o\000\000\000u\000\000\000l\000\000\000d\000\000\000 \000\000\000f\000\000\000i\000\000\000n\000\000\000d\000\000\000 \000\000\000l\000\000\000o\000\000\000c\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000r\000\000\000e\000\000\000l\000\000\000a\000\000\000t\000\000\000e\000\000\000d\000\000\000 \000\000\000t\000\000\000o\000\000\000:\000\000\000 \000\000\000",32,1977784096);
		Result = F1067_9499(tr1, loc2);
		RTHOOK(3);
		tr1 = RTMS32_EX_H("\012\000\000\000",1,10);
		F1067_9497(RTCW(Result), tr1);
		RTHOOK(4);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) ':';
		loc1 = F1065_9395(loc2, tw1, ((EIF_INTEGER_32) 6L));
		RTHOOK(5);
		if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
			RTHOOK(6);
			tr1 = RTMS32_EX_H("M\000\000\000i\000\000\000s\000\000\000s\000\000\000i\000\000\000n\000\000\000g\000\000\000 \000\000\000i\000\000\000r\000\000\000o\000\000\000n\000\000\000 \000\000\000p\000\000\000a\000\000\000c\000\000\000k\000\000\000a\000\000\000g\000\000\000e\000\000\000 \000\000\000\"\000\000\000",22,1278152994);
			tr2 = F1067_9543(loc2, ((EIF_INTEGER_32) 6L), (EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L)));
			tr1 = F1067_9499(tr1, tr2);
			tr2 = RTMS32_EX_H("\"\000\000\000.\000\000\000\012\000\000\000",3,2240010);
			tr1 = F1067_9499(RTCW(tr1), tr2);
			F1067_9497(RTCW(Result), tr1);
			RTHOOK(7);
			tr1 = RTMS32_EX_H("T\000\000\000o\000\000\000 \000\000\000f\000\000\000i\000\000\000x\000\000\000,\000\000\000 \000\000\000i\000\000\000n\000\000\000s\000\000\000t\000\000\000a\000\000\000l\000\000\000l\000\000\000 \000\000\000f\000\000\000r\000\000\000o\000\000\000m\000\000\000 \000\000\000c\000\000\000o\000\000\000m\000\000\000m\000\000\000a\000\000\000n\000\000\000d\000\000\000 \000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000:\000\000\000 \000\000\000i\000\000\000r\000\000\000o\000\000\000n\000\000\000 \000\000\000i\000\000\000n\000\000\000s\000\000\000t\000\000\000a\000\000\000l\000\000\000l\000\000\000 \000\000\000",48,58179616);
			tr2 = F1067_9543(loc2, ((EIF_INTEGER_32) 6L), (EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L)));
			tr1 = F1067_9499(tr1, tr2);
			F1067_9497(RTCW(Result), tr1);
			RTHOOK(8);
			tr1 = RTMS32_EX_H("\012\000\000\000",1,10);
			F1067_9497(RTCW(Result), tr1);
		} else {
			RTHOOK(9);
			tr1 = RTMS32_EX_H("F\000\000\000i\000\000\000x\000\000\000 \000\000\000i\000\000\000r\000\000\000o\000\000\000n\000\000\000 \000\000\000l\000\000\000o\000\000\000c\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000,\000\000\000 \000\000\000i\000\000\000n\000\000\000s\000\000\000t\000\000\000a\000\000\000l\000\000\000l\000\000\000 \000\000\000m\000\000\000i\000\000\000s\000\000\000s\000\000\000i\000\000\000n\000\000\000g\000\000\000 \000\000\000p\000\000\000a\000\000\000c\000\000\000k\000\000\000a\000\000\000g\000\000\000e\000\000\000,\000\000\000 \000\000\000o\000\000\000r\000\000\000 \000\000\000f\000\000\000i\000\000\000x\000\000\000 \000\000\000t\000\000\000h\000\000\000e\000\000\000 \000\000\000c\000\000\000o\000\000\000n\000\000\000f\000\000\000i\000\000\000g\000\000\000u\000\000\000r\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000.\000\000\000",74,434334510);
			F1067_9497(RTCW(Result), tr1);
			RTHOOK(10);
			tr1 = RTMS32_EX_H("\012\000\000\000",1,10);
			F1067_9497(RTCW(Result), tr1);
		}
	} else {
		RTHOOK(11);
		tr1 = RTMS32_EX_H("C\000\000\000o\000\000\000u\000\000\000l\000\000\000d\000\000\000 \000\000\000n\000\000\000o\000\000\000t\000\000\000 \000\000\000o\000\000\000p\000\000\000e\000\000\000n\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000:\000\000\000 \000\000\000",21,251147808);
		Result = F1067_9499(tr1, *(EIF_REFERENCE *)(Current));
		RTHOOK(12);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc3 = tr1;
		if (EIF_TEST(loc3)) {
			RTHOOK(13);
			tr1 = RTMS32_EX_H("\012\000\000\000",1,10);
			tr1 = F1067_9499(tr1, loc3);
			F1067_9497(RTCW(Result), tr1);
		}
	}
	RTHOOK(14);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		RTHOOK(15);
		tr1 = RTMS32_EX_H("\012\000\000\000C\000\000\000o\000\000\000n\000\000\000f\000\000\000i\000\000\000g\000\000\000u\000\000\000r\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000:\000\000\000 \000\000\000",16,2105703968);
		tr1 = F1067_9499(tr1, loc4);
		F1067_9497(RTCW(Result), tr1);
	}
	RTHOOK(16);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit426 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C9/co426.c <==
/*
 * Code for class CONF_ERROR_FILE
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co426.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CONF_ERROR_FILE}.make */
void F944_7300 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	
	
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
}

/* {CONF_ERROR_FILE}.text */
EIF_REFERENCE F944_7305 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(7);
	RTLR(0,loc2);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,Result);
	RTLR(4,tr2);
	RTLR(5,loc3);
	RTLR(6,loc4);
	RTLIU(7);
	
	RTGC;
	tb1 = '\0';
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	loc2 = tr1;
	if (EIF_TEST(loc2)) {
		tr1 = RTMS_EX_H("iron:",5,1920711738);
		tb2 = F1024_7944(loc2, tr1);
		tb1 = tb2;
	}
	if (tb1) {
		tr1 = RTMS32_EX_H("C\000\000\000o\000\000\000u\000\000\000l\000\000\000d\000\000\000 \000\000\000f\000\000\000i\000\000\000n\000\000\000d\000\000\000 \000\000\000l\000\000\000o\000\000\000c\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000r\000\000\000e\000\000\000l\000\000\000a\000\000\000t\000\000\000e\000\000\000d\000\000\000 \000\000\000t\000\000\000o\000\000\000:\000\000\000 \000\000\000",32,1977784096);
		Result = F1033_8305(tr1, loc2);
		tr1 = RTMS32_EX_H("\012\000\000\000",1,10);
		F1033_8303(RTCW(Result), tr1);
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) ':';
		loc1 = F1031_8201(loc2, tw1, ((EIF_INTEGER_32) 6L));
		if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
			tr1 = RTMS32_EX_H("M\000\000\000i\000\000\000s\000\000\000s\000\000\000i\000\000\000n\000\000\000g\000\000\000 \000\000\000i\000\000\000r\000\000\000o\000\000\000n\000\000\000 \000\000\000p\000\000\000a\000\000\000c\000\000\000k\000\000\000a\000\000\000g\000\000\000e\000\000\000 \000\000\000\"\000\000\000",22,1278152994);
			tr2 = F1033_8349(loc2, ((EIF_INTEGER_32) 6L), (EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L)));
			tr1 = F1033_8305(tr1, tr2);
			tr2 = RTMS32_EX_H("\"\000\000\000.\000\000\000\012\000\000\000",3,2240010);
			tr1 = F1033_8305(RTCW(tr1), tr2);
			F1033_8303(RTCW(Result), tr1);
			tr1 = RTMS32_EX_H("T\000\000\000o\000\000\000 \000\000\000f\000\000\000i\000\000\000x\000\000\000,\000\000\000 \000\000\000i\000\000\000n\000\000\000s\000\000\000t\000\000\000a\000\000\000l\000\000\000l\000\000\000 \000\000\000f\000\000\000r\000\000\000o\000\000\000m\000\000\000 \000\000\000c\000\000\000o\000\000\000m\000\000\000m\000\000\000a\000\000\000n\000\000\000d\000\000\000 \000\000\000l\000\000\000i\000\000\000n\000\000\000e\000\000\000:\000\000\000 \000\000\000i\000\000\000r\000\000\000o\000\000\000n\000\000\000 \000\000\000i\000\000\000n\000\000\000s\000\000\000t\000\000\000a\000\000\000l\000\000\000l\000\000\000 \000\000\000",48,58179616);
			tr2 = F1033_8349(loc2, ((EIF_INTEGER_32) 6L), (EIF_INTEGER_32) (loc1 - ((EIF_INTEGER_32) 1L)));
			tr1 = F1033_8305(tr1, tr2);
			F1033_8303(RTCW(Result), tr1);
			tr1 = RTMS32_EX_H("\012\000\000\000",1,10);
			F1033_8303(RTCW(Result), tr1);
		} else {
			tr1 = RTMS32_EX_H("F\000\000\000i\000\000\000x\000\000\000 \000\000\000i\000\000\000r\000\000\000o\000\000\000n\000\000\000 \000\000\000l\000\000\000o\000\000\000c\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000,\000\000\000 \000\000\000i\000\000\000n\000\000\000s\000\000\000t\000\000\000a\000\000\000l\000\000\000l\000\000\000 \000\000\000m\000\000\000i\000\000\000s\000\000\000s\000\000\000i\000\000\000n\000\000\000g\000\000\000 \000\000\000p\000\000\000a\000\000\000c\000\000\000k\000\000\000a\000\000\000g\000\000\000e\000\000\000,\000\000\000 \000\000\000o\000\000\000r\000\000\000 \000\000\000f\000\000\000i\000\000\000x\000\000\000 \000\000\000t\000\000\000h\000\000\000e\000\000\000 \000\000\000c\000\000\000o\000\000\000n\000\000\000f\000\000\000i\000\000\000g\000\000\000u\000\000\000r\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000.\000\000\000",74,434334510);
			F1033_8303(RTCW(Result), tr1);
			tr1 = RTMS32_EX_H("\012\000\000\000",1,10);
			F1033_8303(RTCW(Result), tr1);
		}
	} else {
		tr1 = RTMS32_EX_H("C\000\000\000o\000\000\000u\000\000\000l\000\000\000d\000\000\000 \000\000\000n\000\000\000o\000\000\000t\000\000\000 \000\000\000o\000\000\000p\000\000\000e\000\000\000n\000\000\000 \000\000\000f\000\000\000i\000\000\000l\000\000\000e\000\000\000:\000\000\000 \000\000\000",21,251147808);
		Result = F1033_8305(tr1, *(EIF_REFERENCE *)(Current));
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		loc3 = tr1;
		if (EIF_TEST(loc3)) {
			tr1 = RTMS32_EX_H("\012\000\000\000",1,10);
			tr1 = F1033_8305(tr1, loc3);
			F1033_8303(RTCW(Result), tr1);
		}
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	loc4 = tr1;
	if (EIF_TEST(loc4)) {
		tr1 = RTMS32_EX_H("\012\000\000\000C\000\000\000o\000\000\000n\000\000\000f\000\000\000i\000\000\000g\000\000\000u\000\000\000r\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000:\000\000\000 \000\000\000",16,2105703968);
		tr1 = F1033_8305(tr1, loc4);
		F1033_8303(RTCW(Result), tr1);
	}
	RTLE;
	return Result;
}

/* {CONF_ERROR_FILE}.set_config */
void F944_7306 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) NULL;
	} else {
		tr1 = F1024_7957(RTCW(arg1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	}
	RTLE;
}

/* {CONF_ERROR_FILE}.set_original_file */
void F944_7307 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	tr1 = F1024_7957(RTCW(arg1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTLE;
}

void EIF_Minit426 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
